@@ -46,6 +46,9 @@ NewGameWidget::NewGameWidget(NewGameSetup* newGameSetup, QWidget *parent) :
   qCDebug(KSIRK_LOG);
   setupUi(this);
   
+  const QString nextIcon = isRightToLeft() ? QStringLiteral("go-previous") : QStringLiteral("go-next");
+  nextButton->setIcon(QIcon::fromTheme(nextIcon));
+
   QObject::connect(nextButton, &QAbstractButton::clicked, this, &NewGameWidget::slotOK );
   QObject::connect(cancelButton, &QAbstractButton::clicked, this, &NewGameWidget::slotCancel );
   QObject::connect(skinCombo, &QComboBox::activated, this, &NewGameWidget::slotSkinChanged);
@@ -67,13 +70,6 @@ void NewGameWidget::init(const QString& skin, GameAutomaton::NetworkGameType net
       tcpPortLabel->show();
       tcpPortEntry->show();
     }
-#if HAVE_JABBER_SUPPORT
-    if (netGameType == GameAutomaton::Jabber)
-    {
-      tcpPortLabel->hide();
-      tcpPortEntry->hide();
-    }
-#endif
     m_newGameSetup->setNbNetworkPlayers(1);
     localPlayersNumberEntry->setValue(m_newGameSetup->nbNetworkPlayers());
   }
@@ -130,7 +126,7 @@ void NewGameWidget::fillSkinsCombo()
     {
       KMessageBox::error(nullptr,
                         i18n("Skins directory not found - Verify your installation\nProgram cannot continue"),
-                        i18n("Fatal Error!"));
+                        i18nc("@title:window", "Fatal Error"));
       exit(2);
     }
     qCDebug(KSIRK_LOG) << "Got skins dir name: " << skinsDirName;
